/**
 * Button.js
 * ---------
 * Implements the createButton function and a short test
 * to confirm createButton works properly.
 */

"use strict";

const BUTTON_HEIGHT = 22;
const BUTTON_FONT = "bold 16px Helvetica";
const BUTTON_LABEL_DY = 6;

/**
 * Function: createButton
 * ----------------------
 * Creates a button (as a GCompound) to surround the specified
 * text, as specified in the problem statement.  The reference
 * point of the button is the upper left corner of the smallest
 * rectangle circumscribing the button rendering.
 */
function createButton(text) {
	let button = GCompound();
	let label = GLabel(text);
	let radius = BUTTON_HEIGHT/2;
	let diameter = 2 * radius;
	label.setFont(BUTTON_FONT);
	button.add(GLine(radius, 0, radius + label.getWidth(), 0));
	button.add(GArc(label.getWidth(), 0, diameter, diameter, 270, 180));
	button.add(GLine(radius, diameter, radius + label.getWidth(), diameter));
	button.add(GArc(0, 0, diameter, diameter, 90, 180));
	button.add(label, radius, radius + BUTTON_LABEL_DY);
	return button;
}

const GWINDOW_WIDTH = 300;
const GWINDOW_HEIGHT = 200;

/**
 * Function: TestButton
 * --------------------
 * Exercises the createButton functionality implemented above.  Note: This
 * test is slightly more elaborate than that listed in the practice
 * final exam.
 */
function TestButton() {
   let gw = GWindow(GWINDOW_WIDTH, GWINDOW_HEIGHT);
   placeButton("Hi!", gw, GWINDOW_WIDTH/2, GWINDOW_HEIGHT/2 - 1.5 * BUTTON_HEIGHT);
   placeButton("Central Button", gw, GWINDOW_WIDTH/2, GWINDOW_HEIGHT/2);
   placeButton("Thanks for taking CS106AJ!", gw, GWINDOW_WIDTH/2, GWINDOW_HEIGHT/2 + 1.5 * BUTTON_HEIGHT);
}

/**
 * Function: placeButton
 * ---------------------
 * Places one of our buttons in the supplied graphics windows
 * so that its center overlay the (cx, cy) provided.  The button's
 * text label is supplied as the very first argument.
 */
function placeButton(text, gw, cx, cy) {
	let button = createButton(text);
	gw.add(button, cx - button.getWidth()/2, cy - button.getHeight()/2);
}
