/**
 * GraphicNim.js
 * -------------
 * This program animates a simplified game of Nim.
 */

"use strict";

/* Constants */
const GWINDOW_WIDTH = 496;
const GWINDOW_HEIGHT = 75;
const N_COINS = 11;
const COIN_SIZE = 32;
const COIN_FILL_COLOR = "LightGray";

/* Derived constants */
const COIN_SEP = (GWINDOW_WIDTH - N_COINS * COIN_SIZE)/(N_COINS + 1);

/**
 * Function: GraphicNim
 * --------------------
 * Defines the factory function that manages the entire
 * simulation.
 */
function GraphicNim() {
	let gw = GWindow(GWINDOW_WIDTH, GWINDOW_HEIGHT);
	let coins = createCoinsArray(gw);
	let clickAction = function (e) {
		let coin = gw.getElementAt(e.getX(), e.getY());
		if (coin === null) return;
		let pos = coins.indexOf(coin);
		if (pos < coins.length - 3) return;
		let count = coins.length - pos;
		for (let i = pos; i < coins.length; i++) {
			gw.remove(coins[i]);
		}
		coins.splice(pos, count);
	};
	gw.addEventListener("click", clickAction);
}

/**
 * Function: createCoinsArray
 * --------------------------
 * createCoinsArray constructs and returns an array of N_COINS
 * GOvals to represent each of the coins.  Each coin is properly
 * set in the supplied graphics window so that the array of
 * coins is centered both vertically and horizontally.
 */
function createCoinsArray(gw) {
	let coins = [];
	let y = (gw.getHeight() - COIN_SIZE)/2;
	for (let i = 0; i < N_COINS; i++) {
		let x = COIN_SEP + i * (COIN_SIZE + COIN_SEP);
		let coin = GOval(x, y, COIN_SIZE, COIN_SIZE);
		coin.setFilled(true);
		coin.setFillColor(COIN_FILL_COLOR);
		gw.add(coin);
		coins.push(coin);
	}
	return coins;
}
